@@ -513,6 +513,15 @@ class Client:
         self.__is_authorized = True
         self.logger.info('Authorization is completed')
 
+    async def __auth_logging_out(self):
+        self.logger.info('Auth session is logging out')
+
+    async def __auth_closing(self):
+        self.logger.info('Auth session is closing')
+
+    async def __auth_closed(self):
+        self.logger.info('Auth session is closed')
+
     async def __stop_signal_handler(self, signum: int) -> None:
         self.logger.info('Signal %s received!', signum)
         await self.stop()
@@ -775,6 +784,9 @@ class Client:
             API.Types.AUTHORIZATION_STATE_WAIT_REGISTRATION: self.__register_user,
             API.Types.AUTHORIZATION_STATE_WAIT_PASSWORD: self.__check_authentication_password,
             API.Types.AUTHORIZATION_STATE_READY: self.__auth_completed,
+            API.Types.AUTHORIZATION_STATE_LOGGING_OUT: self.__auth_logging_out,
+            API.Types.AUTHORIZATION_STATE_CLOSING: self.__auth_closing,
+            API.Types.AUTHORIZATION_STATE_CLOSED: self.__auth_closed,
         }
 
         while not self.__is_authorized:
@@ -788,7 +800,7 @@ class Client:
                     if bool(next_action):
                         result = await next_action()
                     else:
-                        self.logger.warning(f'Unhandled authorization state: {self.__current_authorization_state}')
+                        self.logger.error(f'Unhandled authorization state: {self.__current_authorization_state}')
                         break
                 except AioTDLibError as e:
                     # Need to retry previous step
@@ -1845,7 +1857,8 @@ class Client:
                 Chat identifier
 
             from_message_id (:class:`int`)
-                Identifier of the message starting from which history must be fetched; use 0 to get results from the last message
+                Identifier of the message starting from which history must be fetched;
+                use 0 to get results from the last message
 
             limit (:class:`int`)
                 The maximum number of messages to be returned; must be positive
